Commands enum

Inheritance
Available extensions

Values

status → const Commands
const Commands(0x4A)
openFiscalReceipt → const Commands
const Commands(0x30)
registrationOfSale → const Commands
const Commands(0x31)
closeFiscalReceipt → const Commands
const Commands(0x38)
cancelFiscalReceipt → const Commands
const Commands(0x3C)
printingFreeFiscalText → const Commands
const Commands(0x36)
readSubtotal → const Commands
const Commands(0x33)
feedPaper → const Commands
const Commands(0x2C)
paymentAndTotalSum → const Commands
const Commands(0x35)
printSeparatingLine → const Commands
const Commands(0x5C)
openNonFiscalReceipt → const Commands
const Commands(0x26)
closeNonFiscalReceipt → const Commands
const Commands(0x27)
printingFreeNonFiscalText → const Commands
const Commands(0x2A)
statusOfFiscalTransaction → const Commands
const Commands(0x4C)
readWriteParameter → const Commands
const Commands(0xFF)

Properties

code int
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Commands>
A constant List of the values in this enum, in order of their declaration.