TranscationStatus class

Constructors

TranscationStatus({required int isOpen, required int number, required int items, required double amount, required double paid})
TranscationStatus.fromMessage(Message message)
factory

Properties

amount double
final
hashCode int
The hash code for this object.
no setterinherited
isOpen int
final
items int
final
number int
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited