BC50FiscalDevice class
Constructors
Properties
- comm → Communication
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastStatus → Status?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequance ↔ int
-
getter/setter pairinherited
Methods
-
cancelFiscalReceipt(
) → Future< void> -
closeFiscalReceipt(
) → Future< void> -
closeNonFiscalReceipt(
) → Future< void> -
execute(
int command, {String? data}) → Future< Message> -
inherited
-
generateUniqueSaleNumber(
{int? operator}) → Future< String> -
getCurrentOperatorCode(
) → Future< int> -
getCurrentOperatorPassword(
int operator) → Future< String> -
getFiscalTransactionStatus(
) → Future< TranscationStatus> -
getNextFiscalReceiptNumber(
) → Future< int> -
getSerialNumber(
) → Future< String> -
getStatus(
) → Future< Status> -
inherited
-
getSubtotal(
{bool? print, bool? display, DiscountType? discountType, double? discountValue}) → Future< double> -
getUniqueSaleNumber(
) → Future< String> -
isFiscalOpen(
) → bool -
isNonFiscalOpen(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openFiscalReceipt(
{required int opperatorCode, required String opperatorPassword, String? uniqueSaleNumber, required int salePoint, bool invoice = false}) → Future< void> -
openNonFiscalReceipt(
) → Future< void> -
packMessage(
int command, {String? data}) → Uint8List -
inherited
-
paperFeed(
{required int lines}) → Future< void> -
parseBuffer(
) → Future< Message> -
inherited
-
printFiscalText(
{required String text, TextBold? bold, TextItalic? italic, TextHeight? height, TextUnderline? underline, TextAlign? alignment}) → Future< void> -
printNonFiscalText(
{required String text, TextBold? bold, TextItalic? italic, TextHeight? height, TextUnderline? underline, TextAlign? alignment}) → Future< void> -
printSeparatingLine(
{required SeparatingLine type}) → Future< void> -
readPackage(
) → Future< Message> -
inherited
-
readWriteParameter(
{required String name, int? index, String? value}) → Future< String?> -
receiptTotal(
{required int paidMode, required double amountToPay, int? paymentType, int? changeCurrency}) → Future< void> -
registerSales(
{required String productName, required int taxCode, required double price, double? quantity, DiscountType? discountType, double? discountValue, required int department, String? unit}) → Future< void> -
reset(
) → void -
inherited
-
setCriticalStatus(
Uint8List status) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writePackage(
int command, {String? data}) → Future< void> -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited