Device class sealed

Inheritance
Implementers

Properties

comm Communication
finalinherited
hashCode int
The hash code for this object.
no setterinherited
lastStatus Status?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequance int
getter/setter pair

Methods

execute(int command, {String? data}) Future<Message>
getStatus() Future<Status>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packMessage(int command, {String? data}) Uint8List
parseBuffer() Future<Message>
inherited
readPackage() Future<Message>
reset() → void
inherited
setCriticalStatus(Uint8List status) → void
toString() String
A string representation of this object.
inherited
writePackage(int command, {String? data}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited