Message class

Constructors

Message({required int sequence, required int command, required String data, required Status status, String? message})

Properties

command int
final
data String
final
hashCode int
The hash code for this object.
no setterinherited
message String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
final
status Status
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited