Status class

Constructors

Status(Uint8List raw)
Status.empty()

Properties

bytes String
no setter
commandCodeInvalid bool
no setter
commandNotPermitted bool
no setter
coverOpen bool
no setter
endOfPaper bool
no setter
errorAccessingFmData bool
no setter
fiscalReceiptOpen bool
no setter
fmDataFull bool
no setter
generalError bool
no setter
hashCode int
The hash code for this object.
no setterinherited
nonFiscalReceiptOpen bool
no setter
overflow bool
no setter
raw Uint8List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syntaxError bool
no setter

Methods

criticalStatuses(Uint8List criticalStatus) List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
statusDescription(int byteIndex, int bit) String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited