StaticBytes enum

Inheritance
Available extensions

Values

PRE → const StaticBytes
const StaticBytes(1)
LEN → const StaticBytes
const StaticBytes(4)
SEQ → const StaticBytes
const StaticBytes(1)
CMD → const StaticBytes
const StaticBytes(4)
SEP → const StaticBytes
const StaticBytes(1)
STAT → const StaticBytes
const StaticBytes(8)
PST → const StaticBytes
const StaticBytes(1)
BCC → const StaticBytes
const StaticBytes(4)
EOT → const StaticBytes
const StaticBytes(1)

Properties

end int

Available on StaticBytes, provided by the StaticBytesExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
offset int

Available on StaticBytes, provided by the StaticBytesExtension extension

no setter
overhead int

Available on StaticBytes, provided by the StaticBytesExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StaticBytes>
A constant List of the values in this enum, in order of their declaration.